@@ -72,7 +72,10 @@ void NPC::Load(const DataNode &node)
 		else if(node.Token(i) == "evade")
 			mustEvade = true;
 		else if(node.Token(i) == "accompany")
+		{
 			mustAccompany = true;
+			failIf |= ShipEvent::DESTROY;
+		}
 		else
 			node.PrintTrace("Warning: Skipping unrecognized NPC completion condition \"" + node.Token(i) + "\":");
 	}
@@ -474,25 +477,23 @@ bool NPC::HasSucceeded(const System *playerSystem, bool ignoreIfDespawnable) con
 	if(HasFailed())
 		return false;
 
-	// Evaluate the status of each ship in this NPC block. If it has `accompany`
-	// and is alive then it cannot be disabled and must be in the player's system.
-	// If the NPC block has `evade`, the ship can be disabled, destroyed, captured,
-	// or not present.
+	// Evaluate the status of each ship in this NPC block. If it has `accompany`,
+	// it cannot be disabled or destroyed, and must be in the player's system.
+	// Destroyed `accompany` are handled in HasFailed(). If the NPC block has
+	// `evade`, the ship can be disabled, destroyed, captured, or not present.
 	if(mustEvade || mustAccompany)
 		for(const shared_ptr<Ship> &ship : ships)
 		{
 			auto it = actions.find(ship.get());
-			// Captured or destroyed ships have either succeeded or no longer count.
-			if(it->second & (ShipEvent::DESTROY | ShipEvent::CAPTURE))
-				continue;
 			// If a derelict ship has not received any ShipEvents, it is immobile.
 			bool isImmobile = ship->GetPersonality().IsDerelict();
 			// The success status calculation can only be based on recorded
 			// events (and the current system).
 			if(it != actions.end())
 			{
-				// A ship that was disabled is considered 'immobile'.
-				isImmobile = (it->second & ShipEvent::DISABLE);
+				// A ship that was disabled, captured, or destroyed is considered 'immobile'.
+				isImmobile = (it->second
+					& (ShipEvent::DISABLE | ShipEvent::CAPTURE | ShipEvent::DESTROY));
 				// If this NPC is 'derelict' and has no ASSIST on record, it is immobile.
 				isImmobile |= ship->GetPersonality().IsDerelict()
 					&& !(it->second & ShipEvent::ASSIST);
